@@ -22,7 +22,7 @@ from airflow.utils.state import State
 
 
 class DagStateField(fields.String):
-    """Schema for DagState Enum"""
+    """Schema for DagState Enum."""
 
     def __init__(self, **metadata):
         super().__init__(**metadata)
@@ -30,7 +30,7 @@ class DagStateField(fields.String):
 
 
 class TaskInstanceStateField(fields.String):
-    """Schema for TaskInstanceState Enum"""
+    """Schema for TaskInstanceState Enum."""
 
     def __init__(self, **metadata):
         super().__init__(**metadata)
