@@ -127,16 +127,16 @@ class PythonOperator(BaseOperator):
         such as transmission a large amount of XCom to TaskAPI.
     """
 
-    template_fields: Sequence[str] = ('templates_dict', 'op_args', 'op_kwargs')
+    template_fields: Sequence[str] = ("templates_dict", "op_args", "op_kwargs")
     template_fields_renderers = {"templates_dict": "json", "op_args": "py", "op_kwargs": "py"}
-    BLUE = '#ffefeb'
+    BLUE = "#ffefeb"
     ui_color = BLUE
 
     # since we won't mutate the arguments, we should just do the shallow copy
     # there are some cases we can't deepcopy the objects(e.g protobuf).
     shallow_copy_attrs: Sequence[str] = (
-        'python_callable',
-        'op_kwargs',
+        "python_callable",
+        "op_kwargs",
     )
 
     def __init__(
@@ -156,10 +156,10 @@ class PythonOperator(BaseOperator):
                 RemovedInAirflow3Warning,
                 stacklevel=2,
             )
-            kwargs.pop('provide_context', None)
+            kwargs.pop("provide_context", None)
         super().__init__(**kwargs)
         if not callable(python_callable):
-            raise AirflowException('`python_callable` param must be callable')
+            raise AirflowException("`python_callable` param must be callable")
         self.python_callable = python_callable
         self.op_args = op_args or ()
         self.op_kwargs = op_kwargs or {}
@@ -183,12 +183,11 @@ class PythonOperator(BaseOperator):
     def determine_kwargs(self, context: Mapping[str, Any]) -> Mapping[str, Any]:
         return KeywordParameters.determine(self.python_callable, self.op_args, context).unpacking()
 
-    def execute_callable(self):
+    def execute_callable(self) -> Any:
         """
         Calls the python callable with the given arguments.
 
         :return: the return value of the call.
-        :rtype: any
         """
         return self.python_callable(*self.op_args, **self.op_kwargs)
 
@@ -209,22 +208,8 @@ class BranchPythonOperator(PythonOperator, SkipMixin):
 
     def execute(self, context: Context) -> Any:
         branch = super().execute(context)
-        # TODO: The logic should be moved to SkipMixin to be available to all branch operators.
-        if isinstance(branch, str):
-            branches = {branch}
-        elif isinstance(branch, list):
-            branches = set(branch)
-        elif branch is None:
-            branches = set()
-        else:
-            raise AirflowException("Branch callable must return either None, a task ID, or a list of IDs")
-        valid_task_ids = set(context["dag"].task_ids)
-        invalid_task_ids = branches - valid_task_ids
-        if invalid_task_ids:
-            raise AirflowException(
-                f"Branch callable must return valid task_ids. Invalid tasks found: {invalid_task_ids}"
-            )
-        self.skip_all_except(context['ti'], branch)
+        self.log.info("Branch callable return %s", branch)
+        self.skip_all_except(context["ti"], branch)
         return branch
 
 
@@ -263,10 +248,10 @@ class ShortCircuitOperator(PythonOperator, SkipMixin):
         self.log.info("Condition result is %s", condition)
 
         if condition:
-            self.log.info('Proceeding with downstream tasks...')
+            self.log.info("Proceeding with downstream tasks...")
             return condition
 
-        downstream_tasks = context['task'].get_flat_relatives(upstream=False)
+        downstream_tasks = context["task"].get_flat_relatives(upstream=False)
         self.log.debug("Downstream task IDs %s", downstream_tasks)
 
         if downstream_tasks:
@@ -287,45 +272,46 @@ class ShortCircuitOperator(PythonOperator, SkipMixin):
 
 class _BasePythonVirtualenvOperator(PythonOperator, metaclass=ABCMeta):
     BASE_SERIALIZABLE_CONTEXT_KEYS = {
-        'ds',
-        'ds_nodash',
-        'inlets',
-        'next_ds',
-        'next_ds_nodash',
-        'outlets',
-        'prev_ds',
-        'prev_ds_nodash',
-        'run_id',
-        'task_instance_key_str',
-        'test_mode',
-        'tomorrow_ds',
-        'tomorrow_ds_nodash',
-        'ts',
-        'ts_nodash',
-        'ts_nodash_with_tz',
-        'yesterday_ds',
-        'yesterday_ds_nodash',
+        "ds",
+        "ds_nodash",
+        "expanded_ti_count",
+        "inlets",
+        "next_ds",
+        "next_ds_nodash",
+        "outlets",
+        "prev_ds",
+        "prev_ds_nodash",
+        "run_id",
+        "task_instance_key_str",
+        "test_mode",
+        "tomorrow_ds",
+        "tomorrow_ds_nodash",
+        "ts",
+        "ts_nodash",
+        "ts_nodash_with_tz",
+        "yesterday_ds",
+        "yesterday_ds_nodash",
     }
     PENDULUM_SERIALIZABLE_CONTEXT_KEYS = {
-        'data_interval_end',
-        'data_interval_start',
-        'execution_date',
-        'logical_date',
-        'next_execution_date',
-        'prev_data_interval_end_success',
-        'prev_data_interval_start_success',
-        'prev_execution_date',
-        'prev_execution_date_success',
-        'prev_start_date_success',
+        "data_interval_end",
+        "data_interval_start",
+        "execution_date",
+        "logical_date",
+        "next_execution_date",
+        "prev_data_interval_end_success",
+        "prev_data_interval_start_success",
+        "prev_execution_date",
+        "prev_execution_date_success",
+        "prev_start_date_success",
     }
     AIRFLOW_SERIALIZABLE_CONTEXT_KEYS = {
-        'macros',
-        'conf',
-        'dag',
-        'dag_run',
-        'task',
-        'params',
-        'triggering_dataset_events',
+        "macros",
+        "conf",
+        "dag",
+        "dag_run",
+        "task",
+        "params",
+        "triggering_dataset_events",
     }
 
     def __init__(
@@ -346,7 +332,7 @@ class _BasePythonVirtualenvOperator(PythonOperator, metaclass=ABCMeta):
             or isinstance(python_callable, types.LambdaType)
             and python_callable.__name__ == "<lambda>"
         ):
-            raise AirflowException('PythonVirtualenvOperator only supports functions for python_callable arg')
+            raise AirflowException("PythonVirtualenvOperator only supports functions for python_callable arg")
         super().__init__(
             python_callable=python_callable,
             op_args=op_args,
@@ -378,10 +364,10 @@ class _BasePythonVirtualenvOperator(PythonOperator, metaclass=ABCMeta):
 
     def _write_args(self, file: Path):
         if self.op_args or self.op_kwargs:
-            file.write_bytes(self.pickling_library.dumps({'args': self.op_args, 'kwargs': self.op_kwargs}))
+            file.write_bytes(self.pickling_library.dumps({"args": self.op_args, "kwargs": self.op_kwargs}))
 
     def _write_string_args(self, file: Path):
-        file.write_text('\n'.join(map(str, self.string_args)))
+        file.write_text("\n".join(map(str, self.string_args)))
 
     def _read_result(self, path: Path):
         if path.stat().st_size == 0:
@@ -403,11 +389,11 @@ class _BasePythonVirtualenvOperator(PythonOperator, metaclass=ABCMeta):
     def _execute_python_callable_in_subprocess(self, python_path: Path, tmp_dir: Path):
         op_kwargs: dict[str, Any] = {k: v for k, v in self.op_kwargs.items()}
         if self.templates_dict:
-            op_kwargs['templates_dict'] = self.templates_dict
-        input_path = tmp_dir / 'script.in'
-        output_path = tmp_dir / 'script.out'
-        string_args_path = tmp_dir / 'string_args.txt'
-        script_path = tmp_dir / 'script.py'
+            op_kwargs["templates_dict"] = self.templates_dict
+        input_path = tmp_dir / "script.in"
+        output_path = tmp_dir / "script.out"
+        string_args_path = tmp_dir / "string_args.txt"
+        script_path = tmp_dir / "script.py"
         self._write_args(input_path)
         self._write_string_args(string_args_path)
         write_python_script(
@@ -487,8 +473,8 @@ class PythonVirtualenvOperator(_BasePythonVirtualenvOperator):
         macros when starting.
     """
 
-    template_fields: Sequence[str] = tuple({'requirements'} | set(PythonOperator.template_fields))
-    template_ext: Sequence[str] = ('.txt',)
+    template_fields: Sequence[str] = tuple({"requirements"} | set(PythonOperator.template_fields))
+    template_ext: Sequence[str] = (".txt",)
 
     def __init__(
         self,
@@ -518,7 +504,7 @@ class PythonVirtualenvOperator(_BasePythonVirtualenvOperator):
                 f"Sys version: {sys.version_info}. Venv version: {python_version}"
             )
         if not shutil.which("virtualenv"):
-            raise AirflowException('PythonVirtualenvOperator requires virtualenv, please install it.')
+            raise AirflowException("PythonVirtualenvOperator requires virtualenv, please install it.")
         if not requirements:
             self.requirements: list[str] | str = []
         elif isinstance(requirements, str):
@@ -541,9 +527,9 @@ class PythonVirtualenvOperator(_BasePythonVirtualenvOperator):
         )
 
     def execute_callable(self):
-        with TemporaryDirectory(prefix='venv') as tmp_dir:
+        with TemporaryDirectory(prefix="venv") as tmp_dir:
             tmp_path = Path(tmp_dir)
-            requirements_file_name = f'{tmp_dir}/requirements.txt'
+            requirements_file_name = f"{tmp_dir}/requirements.txt"
 
             if not isinstance(self.requirements, str):
                 requirements_file_contents = "\n".join(str(dependency) for dependency in self.requirements)
@@ -551,13 +537,13 @@ class PythonVirtualenvOperator(_BasePythonVirtualenvOperator):
                 requirements_file_contents = self.requirements
 
             if not self.system_site_packages and self.use_dill:
-                requirements_file_contents += '\ndill'
+                requirements_file_contents += "\ndill"
 
-            with open(requirements_file_name, 'w') as file:
+            with open(requirements_file_name, "w") as file:
                 file.write(requirements_file_contents)
             prepare_virtualenv(
                 venv_directory=tmp_dir,
-                python_bin=f'python{self.python_version}' if self.python_version else None,
+                python_bin=f"python{self.python_version}" if self.python_version else None,
                 system_site_packages=self.system_site_packages,
                 requirements_file_path=requirements_file_name,
                 pip_install_options=self.pip_install_options,
@@ -568,10 +554,10 @@ class PythonVirtualenvOperator(_BasePythonVirtualenvOperator):
 
     def _iter_serializable_context_keys(self):
         yield from self.BASE_SERIALIZABLE_CONTEXT_KEYS
-        if self.system_site_packages or 'apache-airflow' in self.requirements:
+        if self.system_site_packages or "apache-airflow" in self.requirements:
             yield from self.AIRFLOW_SERIALIZABLE_CONTEXT_KEYS
             yield from self.PENDULUM_SERIALIZABLE_CONTEXT_KEYS
-        elif 'pendulum' in self.requirements:
+        elif "pendulum" in self.requirements:
             yield from self.PENDULUM_SERIALIZABLE_CONTEXT_KEYS
 
 
@@ -621,7 +607,7 @@ class ExternalPythonOperator(_BasePythonVirtualenvOperator):
         macros when starting.
     """
 
-    template_fields: Sequence[str] = tuple({'python_path'} | set(PythonOperator.template_fields))
+    template_fields: Sequence[str] = tuple({"python"} | set(PythonOperator.template_fields))
 
     def __init__(
         self,
@@ -673,7 +659,7 @@ class ExternalPythonOperator(_BasePythonVirtualenvOperator):
                 "major versions for ExternalPythonOperator. Please use string_args."
                 f"Sys version: {sys.version_info}. Venv version: {python_version_as_list_of_strings}"
             )
-        with TemporaryDirectory(prefix='tmd') as tmp_dir:
+        with TemporaryDirectory(prefix="tmd") as tmp_dir:
             tmp_path = Path(tmp_dir)
             return self._execute_python_callable_in_subprocess(python_path, tmp_path)
 
