@@ -16,17 +16,21 @@
 # specific language governing permissions and limitations
 # under the License.
 """Implements Docker operator"""
+from __future__ import annotations
+
 import ast
-import io
 import pickle
 import tarfile
+import warnings
+from io import BytesIO, StringIO
 from tempfile import TemporaryDirectory
-from typing import TYPE_CHECKING, Dict, Iterable, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Iterable, Sequence
 
 from docker import APIClient, tls  # type: ignore[attr-defined]
 from docker.constants import DEFAULT_TIMEOUT_SECONDS  # type: ignore[attr-defined]
 from docker.errors import APIError  # type: ignore[attr-defined]
-from docker.types import Mount  # type: ignore[attr-defined]
+from docker.types import DeviceRequest, LogConfig, Mount  # type: ignore[attr-defined]
+from dotenv import dotenv_values
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -36,11 +40,11 @@ if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-def stringify(line: Union[str, bytes]):
+def stringify(line: str | bytes):
     """Make sure string is returned even if bytes are passed. Docker stream can return bytes."""
-    decode_method = getattr(line, 'decode', None)
+    decode_method = getattr(line, "decode", None)
     if decode_method:
-        return decode_method(encoding='utf-8', errors='surrogateescape')
+        return decode_method(encoding="utf-8", errors="surrogateescape")
     else:
         return line
 
@@ -84,6 +88,8 @@ class DockerOperator(BaseOperator):
     :param environment: Environment variables to set in the container. (templated)
     :param private_environment: Private environment variables to set in the container.
         These are not templated, and hidden from the website.
+    :param env_file: Relative path to the .env file with environment variables to set in the container.
+        Overridden by variables in the environment parameter. (templated)
     :param force_pull: Pull the docker image on every run. Default is False.
     :param mem_limit: Maximum amount of memory the container can use.
         Either a float value, which represents the limit in bytes,
@@ -125,7 +131,7 @@ class DockerOperator(BaseOperator):
     :param dns_search: Docker custom DNS search domain
     :param auto_remove: Auto-removal of the container on daemon side when the
         container's process exits.
-        The default is False.
+        The default is never.
     :param shm_size: Size of ``/dev/shm`` in bytes. The size must be
         greater than 0. If omitted uses system default.
     :param tty: Allocate pseudo-TTY to the container
@@ -136,58 +142,86 @@ class DockerOperator(BaseOperator):
         file before manually shutting down the image. Useful for cases where users want a pickle serialized
         output that is not posted to logs
     :param retrieve_output_path: path for output file that will be retrieved and passed to xcom
+    :param device_requests: Expose host resources such as GPUs to the container.
+    :param log_opts_max_size: The maximum size of the log before it is rolled.
+        A positive integer plus a modifier representing the unit of measure (k, m, or g).
+        Eg: 10m or 1g Defaults to -1 (unlimited).
+    :param log_opts_max_file: The maximum number of log files that can be present.
+        If rolling the logs creates excess files, the oldest file is removed.
+        Only effective when max-size is also set. A positive integer. Defaults to 1.
+    :param ipc_mode: Set the IPC mode for the container.
     """
 
-    template_fields: Sequence[str] = ('image', 'command', 'environment', 'container_name')
+    template_fields: Sequence[str] = ("image", "command", "environment", "env_file", "container_name")
+    template_fields_renderers = {"env_file": "yaml"}
     template_ext: Sequence[str] = (
-        '.sh',
-        '.bash',
+        ".sh",
+        ".bash",
+        ".env",
     )
 
     def __init__(
         self,
         *,
         image: str,
-        api_version: Optional[str] = None,
-        command: Optional[Union[str, List[str]]] = None,
-        container_name: Optional[str] = None,
+        api_version: str | None = None,
+        command: str | list[str] | None = None,
+        container_name: str | None = None,
         cpus: float = 1.0,
-        docker_url: str = 'unix://var/run/docker.sock',
-        environment: Optional[Dict] = None,
-        private_environment: Optional[Dict] = None,
+        docker_url: str = "unix://var/run/docker.sock",
+        environment: dict | None = None,
+        private_environment: dict | None = None,
+        env_file: str | None = None,
         force_pull: bool = False,
-        mem_limit: Optional[Union[float, str]] = None,
-        host_tmp_dir: Optional[str] = None,
-        network_mode: Optional[str] = None,
-        tls_ca_cert: Optional[str] = None,
-        tls_client_cert: Optional[str] = None,
-        tls_client_key: Optional[str] = None,
-        tls_hostname: Optional[Union[str, bool]] = None,
-        tls_ssl_version: Optional[str] = None,
+        mem_limit: float | str | None = None,
+        host_tmp_dir: str | None = None,
+        network_mode: str | None = None,
+        tls_ca_cert: str | None = None,
+        tls_client_cert: str | None = None,
+        tls_client_key: str | None = None,
+        tls_hostname: str | bool | None = None,
+        tls_ssl_version: str | None = None,
         mount_tmp_dir: bool = True,
-        tmp_dir: str = '/tmp/airflow',
-        user: Optional[Union[str, int]] = None,
-        mounts: Optional[List[Mount]] = None,
-        entrypoint: Optional[Union[str, List[str]]] = None,
-        working_dir: Optional[str] = None,
+        tmp_dir: str = "/tmp/airflow",
+        user: str | int | None = None,
+        mounts: list[Mount] | None = None,
+        entrypoint: str | list[str] | None = None,
+        working_dir: str | None = None,
         xcom_all: bool = False,
-        docker_conn_id: Optional[str] = None,
-        dns: Optional[List[str]] = None,
-        dns_search: Optional[List[str]] = None,
-        auto_remove: bool = False,
-        shm_size: Optional[int] = None,
+        docker_conn_id: str | None = None,
+        dns: list[str] | None = None,
+        dns_search: list[str] | None = None,
+        auto_remove: str = "never",
+        shm_size: int | None = None,
         tty: bool = False,
         privileged: bool = False,
-        cap_add: Optional[Iterable[str]] = None,
-        extra_hosts: Optional[Dict[str, str]] = None,
+        cap_add: Iterable[str] | None = None,
+        extra_hosts: dict[str, str] | None = None,
         retrieve_output: bool = False,
-        retrieve_output_path: Optional[str] = None,
+        retrieve_output_path: str | None = None,
         timeout: int = DEFAULT_TIMEOUT_SECONDS,
+        device_requests: list[DeviceRequest] | None = None,
+        log_opts_max_size: str | None = None,
+        log_opts_max_file: str | None = None,
+        ipc_mode: str | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.api_version = api_version
-        self.auto_remove = auto_remove
+        if type(auto_remove) == bool:
+            warnings.warn(
+                "bool value for auto_remove is deprecated, please use 'never', 'success', or 'force' instead",
+                DeprecationWarning,
+                stacklevel=2,
+            )
+        if str(auto_remove) == "False":
+            self.auto_remove = "never"
+        elif str(auto_remove) == "True":
+            self.auto_remove = "success"
+        elif str(auto_remove) in ("never", "success", "force"):
+            self.auto_remove = auto_remove
+        else:
+            raise ValueError("unsupported auto_remove option, use 'never', 'success', or 'force' instead")
         self.command = command
         self.container_name = container_name
         self.cpus = cpus
@@ -196,6 +230,7 @@ class DockerOperator(BaseOperator):
         self.docker_url = docker_url
         self.environment = environment or {}
         self._private_environment = private_environment or {}
+        self.env_file = env_file
         self.force_pull = force_pull
         self.image = image
         self.mem_limit = mem_limit
@@ -219,14 +254,16 @@ class DockerOperator(BaseOperator):
         self.privileged = privileged
         self.cap_add = cap_add
         self.extra_hosts = extra_hosts
-        if kwargs.get('xcom_push') is not None:
-            raise AirflowException("'xcom_push' was deprecated, use 'BaseOperator.do_xcom_push' instead")
 
         self.cli = None
         self.container = None
         self.retrieve_output = retrieve_output
         self.retrieve_output_path = retrieve_output_path
         self.timeout = timeout
+        self.device_requests = device_requests
+        self.log_opts_max_size = log_opts_max_size
+        self.log_opts_max_file = log_opts_max_file
+        self.ipc_mode = ipc_mode
 
     def get_hook(self) -> DockerHook:
         """
@@ -242,13 +279,13 @@ class DockerOperator(BaseOperator):
             timeout=self.timeout,
         )
 
-    def _run_image(self) -> Optional[Union[List[str], str]]:
+    def _run_image(self) -> list[str] | str | None:
         """Run a Docker container with the provided image"""
-        self.log.info('Starting docker container from image %s', self.image)
+        self.log.info("Starting docker container from image %s", self.image)
         if not self.cli:
             raise Exception("The 'cli' should be initialized before!")
         if self.mount_tmp_dir:
-            with TemporaryDirectory(prefix='airflowtmp', dir=self.host_tmp_dir) as host_tmp_dir_generated:
+            with TemporaryDirectory(prefix="airflowtmp", dir=self.host_tmp_dir) as host_tmp_dir_generated:
                 tmp_mount = Mount(self.tmp_dir, host_tmp_dir_generated, "bind")
                 try:
                     return self._run_image_with_mounts(self.mounts + [tmp_mount], add_tmp_variable=True)
@@ -265,19 +302,25 @@ class DockerOperator(BaseOperator):
         else:
             return self._run_image_with_mounts(self.mounts, add_tmp_variable=False)
 
-    def _run_image_with_mounts(
-        self, target_mounts, add_tmp_variable: bool
-    ) -> Optional[Union[List[str], str]]:
+    def _run_image_with_mounts(self, target_mounts, add_tmp_variable: bool) -> list[str] | str | None:
         if add_tmp_variable:
-            self.environment['AIRFLOW_TMP_DIR'] = self.tmp_dir
+            self.environment["AIRFLOW_TMP_DIR"] = self.tmp_dir
         else:
-            self.environment.pop('AIRFLOW_TMP_DIR', None)
+            self.environment.pop("AIRFLOW_TMP_DIR", None)
         if not self.cli:
             raise Exception("The 'cli' should be initialized before!")
+        docker_log_config = {}
+        if self.log_opts_max_size is not None:
+            docker_log_config["max-size"] = self.log_opts_max_size
+        if self.log_opts_max_file is not None:
+            docker_log_config["max-file"] = self.log_opts_max_file
+        env_file_vars = {}
+        if self.env_file is not None:
+            env_file_vars = self.unpack_environment_variables(self.env_file)
         self.container = self.cli.create_container(
             command=self.format_command(self.command),
             name=self.container_name,
-            environment={**self.environment, **self._private_environment},
+            environment={**env_file_vars, **self.environment, **self._private_environment},
             host_config=self.cli.create_host_config(
                 auto_remove=False,
                 mounts=target_mounts,
@@ -290,6 +333,9 @@ class DockerOperator(BaseOperator):
                 cap_add=self.cap_add,
                 extra_hosts=self.extra_hosts,
                 privileged=self.privileged,
+                device_requests=self.device_requests,
+                log_config=LogConfig(config=docker_log_config),
+                ipc_mode=self.ipc_mode,
             ),
             image=self.image,
             user=self.user,
@@ -297,9 +343,9 @@ class DockerOperator(BaseOperator):
             working_dir=self.working_dir,
             tty=self.tty,
         )
-        logstream = self.cli.attach(container=self.container['Id'], stdout=True, stderr=True, stream=True)
+        logstream = self.cli.attach(container=self.container["Id"], stdout=True, stderr=True, stream=True)
         try:
-            self.cli.start(self.container['Id'])
+            self.cli.start(self.container["Id"])
 
             log_lines = []
             for log_chunk in logstream:
@@ -307,33 +353,30 @@ class DockerOperator(BaseOperator):
                 log_lines.append(log_chunk)
                 self.log.info("%s", log_chunk)
 
-            result = self.cli.wait(self.container['Id'])
-            if result['StatusCode'] != 0:
+            result = self.cli.wait(self.container["Id"])
+            if result["StatusCode"] != 0:
                 joined_log_lines = "\n".join(log_lines)
-                raise AirflowException(f'Docker container failed: {repr(result)} lines {joined_log_lines}')
+                raise AirflowException(f"Docker container failed: {repr(result)} lines {joined_log_lines}")
 
             if self.retrieve_output:
                 return self._attempt_to_retrieve_result()
             elif self.do_xcom_push:
-                log_parameters = {
-                    'container': self.container['Id'],
-                    'stdout': True,
-                    'stderr': True,
-                    'stream': True,
-                }
+                if len(log_lines) == 0:
+                    return None
                 try:
                     if self.xcom_all:
-                        return [stringify(line).strip() for line in self.cli.logs(**log_parameters)]
+                        return log_lines
                     else:
-                        lines = [stringify(line).strip() for line in self.cli.logs(**log_parameters, tail=1)]
-                        return lines[-1] if lines else None
+                        return log_lines[-1]
                 except StopIteration:
                     # handle the case when there is not a single line to iterate on
                     return None
             return None
         finally:
-            if self.auto_remove:
-                self.cli.remove_container(self.container['Id'])
+            if self.auto_remove == "success":
+                self.cli.remove_container(self.container["Id"])
+            elif self.auto_remove == "force":
+                self.cli.remove_container(self.container["Id"], force=True)
 
     def _attempt_to_retrieve_result(self):
         """
@@ -345,22 +388,22 @@ class DockerOperator(BaseOperator):
 
         def copy_from_docker(container_id, src):
             archived_result, stat = self.cli.get_archive(container_id, src)
-            if stat['size'] == 0:
+            if stat["size"] == 0:
                 # 0 byte file, it can't be anything else than None
                 return None
             # no need to port to a file since we intend to deserialize
-            file_standin = io.BytesIO(b"".join(archived_result))
+            file_standin = BytesIO(b"".join(archived_result))
             tar = tarfile.open(fileobj=file_standin)
-            file = tar.extractfile(stat['name'])
-            lib = getattr(self, 'pickling_library', pickle)
+            file = tar.extractfile(stat["name"])
+            lib = getattr(self, "pickling_library", pickle)
             return lib.loads(file.read())
 
         try:
-            return copy_from_docker(self.container['Id'], self.retrieve_output_path)
+            return copy_from_docker(self.container["Id"], self.retrieve_output_path)
         except APIError:
             return None
 
-    def execute(self, context: 'Context') -> Optional[str]:
+    def execute(self, context: Context) -> str | None:
         self.cli = self._get_cli()
         if not self.cli:
             raise Exception("The 'cli' should be initialized before!")
@@ -368,15 +411,15 @@ class DockerOperator(BaseOperator):
         # Pull the docker image if `force_pull` is set or image does not exist locally
 
         if self.force_pull or not self.cli.images(name=self.image):
-            self.log.info('Pulling docker image %s', self.image)
+            self.log.info("Pulling docker image %s", self.image)
             latest_status = {}
             for output in self.cli.pull(self.image, stream=True, decode=True):
                 if isinstance(output, str):
                     self.log.info("%s", output)
                     continue
-                if isinstance(output, dict) and 'status' in output:
+                if isinstance(output, dict) and "status" in output:
                     output_status = output["status"]
-                    if 'id' not in output:
+                    if "id" not in output:
                         self.log.info("%s", output_status)
                         continue
 
@@ -396,28 +439,27 @@ class DockerOperator(BaseOperator):
             )
 
     @staticmethod
-    def format_command(command: Union[str, List[str]]) -> Union[List[str], str]:
+    def format_command(command: str | list[str]) -> list[str] | str:
         """
         Retrieve command(s). if command string starts with [, it returns the command list)
 
         :param command: Docker command or entrypoint
 
         :return: the command (or commands)
-        :rtype: str | List[str]
         """
-        if isinstance(command, str) and command.strip().find('[') == 0:
+        if isinstance(command, str) and command.strip().find("[") == 0:
             return ast.literal_eval(command)
         return command
 
     def on_kill(self) -> None:
         if self.cli is not None:
-            self.log.info('Stopping docker container')
+            self.log.info("Stopping docker container")
             if self.container is None:
-                self.log.info('Not attempting to kill container as it was not created')
+                self.log.info("Not attempting to kill container as it was not created")
                 return
-            self.cli.stop(self.container['Id'])
+            self.cli.stop(self.container["Id"])
 
-    def __get_tls_config(self) -> Optional[tls.TLSConfig]:
+    def __get_tls_config(self) -> tls.TLSConfig | None:
         tls_config = None
         if self.tls_ca_cert and self.tls_client_cert and self.tls_client_key:
             # Ignore type error on SSL version here - it is deprecated and type annotation is wrong
@@ -429,5 +471,16 @@ class DockerOperator(BaseOperator):
                 ssl_version=self.tls_ssl_version,
                 assert_hostname=self.tls_hostname,
             )
-            self.docker_url = self.docker_url.replace('tcp://', 'https://')
+            self.docker_url = self.docker_url.replace("tcp://", "https://")
         return tls_config
+
+    @staticmethod
+    def unpack_environment_variables(env_str: str) -> dict:
+        r"""
+        Parse environment variables from the string
+
+        :param env_str: environment variables in key=value format separated by '\n'
+
+        :return: dictionary containing parsed environment variables
+        """
+        return dotenv_values(stream=StringIO(env_str))
