@@ -14,35 +14,32 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-from typing import List, Optional
+from __future__ import annotations
 
 import hvac
-
-try:
-    from functools import cached_property
-except ImportError:
-    from cached_property import cached_property
+from hvac.api.auth_methods import Kubernetes
 from hvac.exceptions import InvalidPath, VaultError
 from requests import Response
 
+from airflow.compat.functools import cached_property
 from airflow.utils.log.logging_mixin import LoggingMixin
 
-DEFAULT_KUBERNETES_JWT_PATH = '/var/run/secrets/kubernetes.io/serviceaccount/token'
+DEFAULT_KUBERNETES_JWT_PATH = "/var/run/secrets/kubernetes.io/serviceaccount/token"
 DEFAULT_KV_ENGINE_VERSION = 2
 
 
-VALID_KV_VERSIONS: List[int] = [1, 2]
-VALID_AUTH_TYPES: List[str] = [
-    'approle',
-    'aws_iam',
-    'azure',
-    'github',
-    'gcp',
-    'kubernetes',
-    'ldap',
-    'radius',
-    'token',
-    'userpass',
+VALID_KV_VERSIONS: list[int] = [1, 2]
+VALID_AUTH_TYPES: list[str] = [
+    "approle",
+    "aws_iam",
+    "azure",
+    "github",
+    "gcp",
+    "kubernetes",
+    "ldap",
+    "radius",
+    "token",
+    "userpass",
 ]
 
 
@@ -54,85 +51,63 @@ class _VaultClient(LoggingMixin):
     with VaultHook using standard Airflow Connection definition.
 
     :param url: Base URL for the Vault instance being addressed.
-    :type url: str
     :param auth_type: Authentication Type for Vault. Default is ``token``. Available values are in
         ('approle', 'aws_iam', 'azure', 'github', 'gcp', 'kubernetes', 'ldap', 'radius', 'token', 'userpass')
-    :type auth_type: str
     :param auth_mount_point: It can be used to define mount_point for authentication chosen
           Default depends on the authentication method used.
-    :type auth_mount_point: str
     :param mount_point: The "path" the secret engine was mounted on. Default is "secret". Note that
          this mount_point is not used for authentication if authentication is done via a
          different engine. For authentication mount_points see, auth_mount_point.
-    :type mount_point: str
     :param kv_engine_version: Selects the version of the engine to run (``1`` or ``2``, default: ``2``).
-    :type kv_engine_version: int
     :param token: Authentication token to include in requests sent to Vault
         (for ``token`` and ``github`` auth_type).
-    :type token: str
     :param token_path: path to file containing authentication token to include in requests sent to Vault
         (for ``token`` and ``github`` auth_type).
-    :type token_path: str
     :param username: Username for Authentication (for ``ldap`` and ``userpass`` auth_types).
-    :type username: str
     :param password: Password for Authentication (for ``ldap`` and ``userpass`` auth_types).
-    :type password: str
     :param key_id: Key ID for Authentication (for ``aws_iam`` and ''azure`` auth_type).
-    :type  key_id: str
     :param secret_id: Secret ID for Authentication (for ``approle``, ``aws_iam`` and ``azure`` auth_types).
-    :type secret_id: str
     :param role_id: Role ID for Authentication (for ``approle``, ``aws_iam`` auth_types).
-    :type role_id: str
     :param kubernetes_role: Role for Authentication (for ``kubernetes`` auth_type).
-    :type kubernetes_role: str
     :param kubernetes_jwt_path: Path for kubernetes jwt token (for ``kubernetes`` auth_type, default:
         ``/var/run/secrets/kubernetes.io/serviceaccount/token``).
-    :type kubernetes_jwt_path: str
     :param gcp_key_path: Path to Google Cloud Service Account key file (JSON)  (for ``gcp`` auth_type).
            Mutually exclusive with gcp_keyfile_dict
-    :type gcp_key_path: str
     :param gcp_keyfile_dict: Dictionary of keyfile parameters. (for ``gcp`` auth_type).
            Mutually exclusive with gcp_key_path
-    :type gcp_keyfile_dict: dict
     :param gcp_scopes: Comma-separated string containing OAuth2 scopes (for ``gcp`` auth_type).
-    :type gcp_scopes: str
     :param azure_tenant_id: The tenant id for the Azure Active Directory (for ``azure`` auth_type).
-    :type azure_tenant_id: str
     :param azure_resource: The configured URL for the application registered in Azure Active Directory
            (for ``azure`` auth_type).
-    :type azure_resource: str
     :param radius_host: Host for radius (for ``radius`` auth_type).
-    :type radius_host: str
     :param radius_secret: Secret for radius (for ``radius`` auth_type).
-    :type radius_secret: str
     :param radius_port: Port for radius (for ``radius`` auth_type).
-    :type radius_port: int
     """
 
     def __init__(
         self,
-        url: Optional[str] = None,
-        auth_type: str = 'token',
-        auth_mount_point: Optional[str] = None,
+        url: str | None = None,
+        auth_type: str = "token",
+        auth_mount_point: str | None = None,
         mount_point: str = "secret",
-        kv_engine_version: Optional[int] = None,
-        token: Optional[str] = None,
-        token_path: Optional[str] = None,
-        username: Optional[str] = None,
-        password: Optional[str] = None,
-        key_id: Optional[str] = None,
-        secret_id: Optional[str] = None,
-        role_id: Optional[str] = None,
-        kubernetes_role: Optional[str] = None,
-        kubernetes_jwt_path: Optional[str] = '/var/run/secrets/kubernetes.io/serviceaccount/token',
-        gcp_key_path: Optional[str] = None,
-        gcp_keyfile_dict: Optional[dict] = None,
-        gcp_scopes: Optional[str] = None,
-        azure_tenant_id: Optional[str] = None,
-        azure_resource: Optional[str] = None,
-        radius_host: Optional[str] = None,
-        radius_secret: Optional[str] = None,
-        radius_port: Optional[int] = None,
+        kv_engine_version: int | None = None,
+        token: str | None = None,
+        token_path: str | None = None,
+        username: str | None = None,
+        password: str | None = None,
+        key_id: str | None = None,
+        secret_id: str | None = None,
+        role_id: str | None = None,
+        kubernetes_role: str | None = None,
+        kubernetes_jwt_path: str | None = "/var/run/secrets/kubernetes.io/serviceaccount/token",
+        gcp_key_path: str | None = None,
+        gcp_keyfile_dict: dict | None = None,
+        gcp_scopes: str | None = None,
+        azure_tenant_id: str | None = None,
+        azure_resource: str | None = None,
+        radius_host: str | None = None,
+        radius_secret: str | None = None,
+        radius_port: int | None = None,
         **kwargs,
     ):
         super().__init__()
@@ -143,7 +118,7 @@ class _VaultClient(LoggingMixin):
             )
         if auth_type not in VALID_AUTH_TYPES:
             raise VaultError(
-                f"The auth_type is not supported: {auth_type}. " f"It should be one of {VALID_AUTH_TYPES}"
+                f"The auth_type is not supported: {auth_type}. It should be one of {VALID_AUTH_TYPES}"
             )
         if auth_type == "token" and not token and not token_path:
             raise VaultError("The 'token' authentication type requires 'token' or 'token_path'")
@@ -198,14 +173,13 @@ class _VaultClient(LoggingMixin):
         it is still authenticated to Vault, and invalidates the cache if this
         is not the case.
 
-        :rtype: hvac.Client
         :return: Vault Client
 
         """
         if not self._client.is_authenticated():
             # Invalidate the cache:
             # https://github.com/pydanny/cached-property#invalidating-the-cache
-            self.__dict__.pop('_client', None)
+            self.__dict__.pop("_client", None)
         return self._client
 
     @cached_property
@@ -213,16 +187,15 @@ class _VaultClient(LoggingMixin):
         """
         Return an authenticated Hashicorp Vault client.
 
-        :rtype: hvac.Client
         :return: Vault Client
 
         """
         _client = hvac.Client(url=self.url, **self.kwargs)
         if self.auth_type == "approle":
             self._auth_approle(_client)
-        elif self.auth_type == 'aws_iam':
+        elif self.auth_type == "aws_iam":
             self._auth_aws_iam(_client)
-        elif self.auth_type == 'azure':
+        elif self.auth_type == "azure":
             self._auth_azure(_client)
         elif self.auth_type == "gcp":
             self._auth_gcp(_client)
@@ -281,9 +254,11 @@ class _VaultClient(LoggingMixin):
         with open(self.kubernetes_jwt_path) as f:
             jwt = f.read().strip()
             if self.auth_mount_point:
-                _client.auth_kubernetes(role=self.kubernetes_role, jwt=jwt, mount_point=self.auth_mount_point)
+                Kubernetes(_client.adapter).login(
+                    role=self.kubernetes_role, jwt=jwt, mount_point=self.auth_mount_point
+                )
             else:
-                _client.auth_kubernetes(role=self.kubernetes_role, jwt=jwt)
+                Kubernetes(_client.adapter).login(role=self.kubernetes_role, jwt=jwt)
 
     def _auth_github(self, _client: hvac.Client) -> None:
         if self.auth_mount_point:
@@ -349,15 +324,13 @@ class _VaultClient(LoggingMixin):
         else:
             _client.token = self.token
 
-    def get_secret(self, secret_path: str, secret_version: Optional[int] = None) -> Optional[dict]:
+    def get_secret(self, secret_path: str, secret_version: int | None = None) -> dict | None:
         """
         Get secret value from the KV engine.
 
         :param secret_path: The path of the secret.
-        :type secret_path: str
         :param secret_version: Specifies the version of Secret to return. If not set, the latest
             version is returned. (Can only be used in case of version 2 of KV).
-        :type secret_version: int
 
         See https://hvac.readthedocs.io/en/stable/usage/secrets_engines/kv_v1.html
         and https://hvac.readthedocs.io/en/stable/usage/secrets_engines/kv_v2.html for details.
@@ -382,13 +355,11 @@ class _VaultClient(LoggingMixin):
         return_data = response["data"] if self.kv_engine_version == 1 else response["data"]["data"]
         return return_data
 
-    def get_secret_metadata(self, secret_path: str) -> Optional[dict]:
+    def get_secret_metadata(self, secret_path: str) -> dict | None:
         """
         Reads secret metadata (including versions) from the engine. It is only valid for KV version 2.
 
         :param secret_path: The path of the secret.
-        :type secret_path: str
-        :rtype: dict
         :return: secret metadata. This is a Dict containing metadata for the secret.
 
                  See https://hvac.readthedocs.io/en/stable/usage/secrets_engines/kv_v2.html for details.
@@ -405,19 +376,16 @@ class _VaultClient(LoggingMixin):
             return None
 
     def get_secret_including_metadata(
-        self, secret_path: str, secret_version: Optional[int] = None
-    ) -> Optional[dict]:
+        self, secret_path: str, secret_version: int | None = None
+    ) -> dict | None:
         """
         Reads secret including metadata. It is only valid for KV version 2.
 
         See https://hvac.readthedocs.io/en/stable/usage/secrets_engines/kv_v2.html for details.
 
         :param secret_path: The path of the secret.
-        :type secret_path: str
         :param secret_version: Specifies the version of Secret to return. If not set, the latest
             version is returned. (Can only be used in case of version 2 of KV).
-        :type secret_version: int
-        :rtype: dict
         :return: The key info. This is a Dict with "data" mapping keeping secret
                  and "metadata" mapping keeping metadata of the secret.
         """
@@ -437,25 +405,20 @@ class _VaultClient(LoggingMixin):
             return None
 
     def create_or_update_secret(
-        self, secret_path: str, secret: dict, method: Optional[str] = None, cas: Optional[int] = None
+        self, secret_path: str, secret: dict, method: str | None = None, cas: int | None = None
     ) -> Response:
         """
         Creates or updates secret.
 
         :param secret_path: The path of the secret.
-        :type secret_path: str
         :param secret: Secret to create or update for the path specified
-        :type secret: dict
         :param method: Optional parameter to explicitly request a POST (create) or PUT (update) request to
             the selected kv secret engine. If no argument is provided for this parameter, hvac attempts to
             intelligently determine which method is appropriate. Only valid for KV engine version 1
-        :type method: str
         :param cas: Set the "cas" value to use a Check-And-Set operation. If not set the write will be
             allowed. If set to 0 a write will only be allowed if the key doesn't exist.
             If the index is non-zero the write will only be allowed if the key's current version
             matches the version specified in the cas parameter. Only valid for KV engine version 2.
-        :type cas: int
-        :rtype: requests.Response
         :return: The response of the create_or_update_secret request.
 
                  See https://hvac.readthedocs.io/en/stable/usage/secrets_engines/kv_v1.html
