@@ -16,8 +16,10 @@
 # specific language governing permissions and limitations
 # under the License.
 """Objects relating to sourcing connections & variables from Hashicorp Vault"""
+from __future__ import annotations
+
 import warnings
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING
 
 from airflow.providers.hashicorp._internal_client.vault_client import _VaultClient
 from airflow.secrets import BaseSecretsBackend
@@ -86,44 +88,44 @@ class VaultBackend(BaseSecretsBackend, LoggingMixin):
 
     def __init__(
         self,
-        connections_path: str = 'connections',
-        variables_path: str = 'variables',
-        config_path: str = 'config',
-        url: Optional[str] = None,
-        auth_type: str = 'token',
-        auth_mount_point: Optional[str] = None,
-        mount_point: str = 'secret',
+        connections_path: str = "connections",
+        variables_path: str = "variables",
+        config_path: str = "config",
+        url: str | None = None,
+        auth_type: str = "token",
+        auth_mount_point: str | None = None,
+        mount_point: str = "secret",
         kv_engine_version: int = 2,
-        token: Optional[str] = None,
-        token_path: Optional[str] = None,
-        username: Optional[str] = None,
-        password: Optional[str] = None,
-        key_id: Optional[str] = None,
-        secret_id: Optional[str] = None,
-        role_id: Optional[str] = None,
-        kubernetes_role: Optional[str] = None,
-        kubernetes_jwt_path: str = '/var/run/secrets/kubernetes.io/serviceaccount/token',
-        gcp_key_path: Optional[str] = None,
-        gcp_keyfile_dict: Optional[dict] = None,
-        gcp_scopes: Optional[str] = None,
-        azure_tenant_id: Optional[str] = None,
-        azure_resource: Optional[str] = None,
-        radius_host: Optional[str] = None,
-        radius_secret: Optional[str] = None,
-        radius_port: Optional[int] = None,
+        token: str | None = None,
+        token_path: str | None = None,
+        username: str | None = None,
+        password: str | None = None,
+        key_id: str | None = None,
+        secret_id: str | None = None,
+        role_id: str | None = None,
+        kubernetes_role: str | None = None,
+        kubernetes_jwt_path: str = "/var/run/secrets/kubernetes.io/serviceaccount/token",
+        gcp_key_path: str | None = None,
+        gcp_keyfile_dict: dict | None = None,
+        gcp_scopes: str | None = None,
+        azure_tenant_id: str | None = None,
+        azure_resource: str | None = None,
+        radius_host: str | None = None,
+        radius_secret: str | None = None,
+        radius_port: int | None = None,
         **kwargs,
     ):
         super().__init__()
         if connections_path is not None:
-            self.connections_path = connections_path.rstrip('/')
+            self.connections_path = connections_path.rstrip("/")
         else:
             self.connections_path = connections_path
         if variables_path is not None:
-            self.variables_path = variables_path.rstrip('/')
+            self.variables_path = variables_path.rstrip("/")
         else:
             self.variables_path = variables_path
         if config_path is not None:
-            self.config_path = config_path.rstrip('/')
+            self.config_path = config_path.rstrip("/")
         else:
             self.config_path = config_path
         self.mount_point = mount_point
@@ -154,11 +156,10 @@ class VaultBackend(BaseSecretsBackend, LoggingMixin):
             **kwargs,
         )
 
-    def get_response(self, conn_id: str) -> Optional[dict]:
+    def get_response(self, conn_id: str) -> dict | None:
         """
         Get data from Vault
 
-        :rtype: dict
         :return: The data from the Vault path if exists
         """
         if self.connections_path is None:
@@ -167,12 +168,11 @@ class VaultBackend(BaseSecretsBackend, LoggingMixin):
         secret_path = self.build_path(self.connections_path, conn_id)
         return self.vault_client.get_secret(secret_path=secret_path)
 
-    def get_conn_uri(self, conn_id: str) -> Optional[str]:
+    def get_conn_uri(self, conn_id: str) -> str | None:
         """
         Get serialized representation of connection
 
         :param conn_id: The connection id
-        :rtype: str
         :return: The connection uri retrieved from the secret
         """
         # Since VaultBackend implements `get_connection`, `get_conn_uri` is not used. So we
@@ -191,12 +191,11 @@ class VaultBackend(BaseSecretsBackend, LoggingMixin):
     if TYPE_CHECKING:
         from airflow.models.connection import Connection
 
-    def get_connection(self, conn_id: str) -> 'Optional[Connection]':
+    def get_connection(self, conn_id: str) -> Connection | None:
         """
         Get connection from Vault as secret. Prioritize conn_uri if exists,
         if not fall back to normal Connection creation.
 
-        :rtype: Connection
         :return: A Connection object constructed from Vault data
         """
         # The Connection needs to be locally imported because otherwise we get into cyclic import
@@ -213,12 +212,11 @@ class VaultBackend(BaseSecretsBackend, LoggingMixin):
 
         return Connection(conn_id, **response)
 
-    def get_variable(self, key: str) -> Optional[str]:
+    def get_variable(self, key: str) -> str | None:
         """
         Get Airflow Variable
 
         :param key: Variable Key
-        :rtype: str
         :return: Variable Value retrieved from the vault
         """
         if self.variables_path is None:
@@ -228,12 +226,11 @@ class VaultBackend(BaseSecretsBackend, LoggingMixin):
             response = self.vault_client.get_secret(secret_path=secret_path)
             return response.get("value") if response else None
 
-    def get_config(self, key: str) -> Optional[str]:
+    def get_config(self, key: str) -> str | None:
         """
         Get Airflow Configuration
 
         :param key: Configuration Option Key
-        :rtype: str
         :return: Configuration Option Value retrieved from the vault
         """
         if self.config_path is None:
