@@ -15,10 +15,13 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 import json
 import warnings
-from typing import TYPE_CHECKING, Any, Dict, List, Optional
+from functools import wraps
+from pathlib import Path
+from typing import TYPE_CHECKING, Any, Sequence
 
 from slack_sdk import WebClient
 from slack_sdk.errors import SlackApiError
@@ -26,7 +29,7 @@ from slack_sdk.errors import SlackApiError
 from airflow.compat.functools import cached_property
 from airflow.exceptions import AirflowException, AirflowNotFoundException
 from airflow.hooks.base import BaseHook
-from airflow.providers.slack.utils import ConnectionExtraConfig, prefixed_extra_field
+from airflow.providers.slack.utils import ConnectionExtraConfig
 from airflow.utils.log.secrets_masker import mask_secret
 
 if TYPE_CHECKING:
@@ -34,6 +37,34 @@ if TYPE_CHECKING:
     from slack_sdk.web.slack_response import SlackResponse
 
 
+def _ensure_prefixes(conn_type):
+    """
+    Remove when provider min airflow version >= 2.5.0 since this is handled by
+    provider manager from that version.
+    """
+
+    def dec(func):
+        @wraps(func)
+        def inner(cls):
+            field_behaviors = func(cls)
+            conn_attrs = {"host", "schema", "login", "password", "port", "extra"}
+
+            def _ensure_prefix(field):
+                if field not in conn_attrs and not field.startswith("extra__"):
+                    return f"extra__{conn_type}__{field}"
+                else:
+                    return field
+
+            if "placeholders" in field_behaviors:
+                placeholders = field_behaviors["placeholders"]
+                field_behaviors["placeholders"] = {_ensure_prefix(k): v for k, v in placeholders.items()}
+            return field_behaviors
+
+        return inner
+
+    return dec
+
+
 class SlackHook(BaseHook):
     """
     Creates a Slack API Connection to be used for calls.
@@ -47,7 +78,7 @@ class SlackHook(BaseHook):
 
     .. warning::
         This hook intend to use `Slack API` connection
-        and might not work correctly with `Slack Webhook` and `HTTP` connections.
+        and might not work correctly with `Slack Incoming Webhook` and `HTTP` connections.
 
     Takes both Slack API token directly and connection that has Slack API token. If both are
     supplied, Slack API token will be used. Also exposes the rest of slack.WebClient args.
@@ -72,24 +103,24 @@ class SlackHook(BaseHook):
         and receive a response from Slack. If not set than default WebClient value will use.
     :param base_url: A string representing the Slack API base URL.
         If not set than default WebClient BASE_URL will use (``https://www.slack.com/api/``).
-    :param proxy: Proxy to make the Slack Incoming Webhook call.
-    :param retry_handlers: List of handlers to customize retry logic in WebClient.
+    :param proxy: Proxy to make the Slack API call.
+    :param retry_handlers: List of handlers to customize retry logic in ``slack_sdk.WebClient``.
     :param token: (deprecated) Slack API Token.
     """
 
-    conn_name_attr = 'slack_conn_id'
-    default_conn_name = 'slack_api_default'
-    conn_type = 'slack'
-    hook_name = 'Slack API'
+    conn_name_attr = "slack_conn_id"
+    default_conn_name = "slack_api_default"
+    conn_type = "slack"
+    hook_name = "Slack API"
 
     def __init__(
         self,
-        token: Optional[str] = None,
-        slack_conn_id: Optional[str] = None,
-        base_url: Optional[str] = None,
-        timeout: Optional[int] = None,
-        proxy: Optional[str] = None,
-        retry_handlers: Optional[List["RetryHandler"]] = None,
+        token: str | None = None,
+        slack_conn_id: str | None = None,
+        base_url: str | None = None,
+        timeout: int | None = None,
+        proxy: str | None = None,
+        retry_handlers: list[RetryHandler] | None = None,
         **extra_client_args: Any,
     ) -> None:
         if not token and not slack_conn_id:
@@ -130,10 +161,10 @@ class SlackHook(BaseHook):
         """Get the underlying slack_sdk.WebClient (cached)."""
         return self.client
 
-    def _get_conn_params(self) -> Dict[str, Any]:
+    def _get_conn_params(self) -> dict[str, Any]:
         """Fetch connection params as a dict and merge it with hook parameters."""
         conn = self.get_connection(self.slack_conn_id) if self.slack_conn_id else None
-        conn_params: Dict[str, Any] = {}
+        conn_params: dict[str, Any] = {"retry_handlers": self.retry_handlers}
 
         if self._token:
             conn_params["token"] = self._token
@@ -156,9 +187,6 @@ class SlackHook(BaseHook):
                 "timeout": self.timeout or extra_config.getint("timeout", default=None),
                 "base_url": self.base_url or extra_config.get("base_url", default=None),
                 "proxy": self.proxy or extra_config.get("proxy", default=None),
-                "retry_handlers": (
-                    self.retry_handlers or extra_config.getimports("retry_handlers", default=None)
-                ),
             }
         )
 
@@ -190,13 +218,13 @@ class SlackHook(BaseHook):
         if slack_conn_id is not None:
             conn = self.get_connection(slack_conn_id)
 
-            if not getattr(conn, 'password', None):
-                raise AirflowException('Missing token(password) in Slack connection')
+            if not getattr(conn, "password", None):
+                raise AirflowException("Missing token(password) in Slack connection")
             return conn.password
 
-        raise AirflowException('Cannot get token: No valid Slack token nor slack_conn_id supplied.')
+        raise AirflowException("Cannot get token: No valid Slack token nor slack_conn_id supplied.")
 
-    def call(self, api_method: str, **kwargs) -> "SlackResponse":
+    def call(self, api_method: str, **kwargs) -> SlackResponse:
         """
         Calls Slack WebClient `WebClient.api_call` with given arguments.
 
@@ -213,6 +241,58 @@ class SlackHook(BaseHook):
         """
         return self.client.api_call(api_method, **kwargs)
 
+    def send_file(
+        self,
+        *,
+        channels: str | Sequence[str] | None = None,
+        file: str | Path | None = None,
+        content: str | None = None,
+        filename: str | None = None,
+        filetype: str | None = None,
+        initial_comment: str | None = None,
+        title: str | None = None,
+    ) -> SlackResponse:
+        """
+        Create or upload an existing file.
+
+        :param channels: Comma-separated list of channel names or IDs where the file will be shared.
+            If omitting this parameter, then file will send to workspace.
+        :param file: Path to file which need to be sent.
+        :param content: File contents. If omitting this parameter, you must provide a file.
+        :param filename: Displayed filename.
+        :param filetype: A file type identifier.
+        :param initial_comment: The message text introducing the file in specified ``channels``.
+        :param title: Title of file.
+
+        .. seealso::
+            - `Slack API files.upload method <https://api.slack.com/methods/files.upload>`_
+            - `File types <https://api.slack.com/types/file#file_types>`_
+        """
+        if not ((not file) ^ (not content)):
+            raise ValueError("Either `file` or `content` must be provided, not both.")
+        elif file:
+            file = Path(file)
+            with open(file, "rb") as fp:
+                if not filename:
+                    filename = file.name
+                return self.client.files_upload(
+                    file=fp,
+                    filename=filename,
+                    filetype=filetype,
+                    initial_comment=initial_comment,
+                    title=title,
+                    channels=channels,
+                )
+
+        return self.client.files_upload(
+            content=content,
+            filename=filename,
+            filetype=filetype,
+            initial_comment=initial_comment,
+            title=title,
+            channels=channels,
+        )
+
     def test_connection(self):
         """Tests the Slack API connection.
 
@@ -237,39 +317,36 @@ class SlackHook(BaseHook):
             return True, str(response)
 
     @classmethod
-    def get_connection_form_widgets(cls) -> Dict[str, Any]:
+    def get_connection_form_widgets(cls) -> dict[str, Any]:
         """Returns dictionary of widgets to be added for the hook to handle extra values."""
         from flask_appbuilder.fieldwidgets import BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import IntegerField, StringField
+        from wtforms.validators import NumberRange, Optional
 
         return {
-            prefixed_extra_field("timeout", cls.conn_type): IntegerField(
+            "timeout": IntegerField(
                 lazy_gettext("Timeout"),
                 widget=BS3TextFieldWidget(),
+                validators=[Optional(strip_whitespace=True), NumberRange(min=1)],
                 description="Optional. The maximum number of seconds the client will wait to connect "
                 "and receive a response from Slack API.",
             ),
-            prefixed_extra_field("base_url", cls.conn_type): StringField(
-                lazy_gettext('Base URL'),
+            "base_url": StringField(
+                lazy_gettext("Base URL"),
                 widget=BS3TextFieldWidget(),
                 description="Optional. A string representing the Slack API base URL.",
             ),
-            prefixed_extra_field("proxy", cls.conn_type): StringField(
-                lazy_gettext('Proxy'),
+            "proxy": StringField(
+                lazy_gettext("Proxy"),
                 widget=BS3TextFieldWidget(),
                 description="Optional. Proxy to make the Slack API call.",
             ),
-            prefixed_extra_field("retry_handlers", cls.conn_type): StringField(
-                lazy_gettext('Retry Handlers'),
-                widget=BS3TextFieldWidget(),
-                description="Optional. Comma separated list of import paths to zero-argument callable "
-                "which returns retry handler for Slack WebClient.",
-            ),
         }
 
     @classmethod
-    def get_ui_field_behaviour(cls) -> Dict[str, Any]:
+    @_ensure_prefixes(conn_type="slack")
+    def get_ui_field_behaviour(cls) -> dict[str, Any]:
         """Returns custom field behaviour."""
         return {
             "hidden_fields": ["login", "port", "host", "schema", "extra"],
@@ -278,12 +355,8 @@ class SlackHook(BaseHook):
             },
             "placeholders": {
                 "password": "xoxb-1234567890123-09876543210987-AbCdEfGhIjKlMnOpQrStUvWx",
-                prefixed_extra_field("timeout", cls.conn_type): "30",
-                prefixed_extra_field("base_url", cls.conn_type): "https://www.slack.com/api/",
-                prefixed_extra_field("proxy", cls.conn_type): "http://localhost:9000",
-                prefixed_extra_field("retry_handlers", cls.conn_type): (
-                    "slack_sdk.http_retry.builtin_handlers.ConnectionErrorRetryHandler,"
-                    "slack_sdk.http_retry.builtin_handlers.RateLimitErrorRetryHandler"
-                ),
+                "timeout": "30",
+                "base_url": "https://www.slack.com/api/",
+                "proxy": "http://localhost:9000",
             },
         }
