@@ -15,10 +15,11 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
 
 import warnings
 from base64 import b64encode
-from typing import TYPE_CHECKING, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.configuration import conf
 from airflow.exceptions import AirflowException
@@ -49,10 +50,8 @@ class SSHOperator(BaseOperator):
         Nullable. If provided, it will replace the `conn_timeout` which was
         predefined in the connection of `ssh_conn_id`.
     :param cmd_timeout: timeout (in seconds) for executing the command. The default is 10 seconds.
-    :param timeout: (deprecated) timeout (in seconds) for executing the command. The default is 10 seconds.
-        Use conn_timeout and cmd_timeout parameters instead.
     :param environment: a dict of shell environment variables. Note that the
-        server will reject them silently if `AcceptEnv` is not set in SSH config.
+        server will reject them silently if `AcceptEnv` is not set in SSH config. (templated)
     :param get_pty: request a pseudo-terminal from the server. Set to ``True``
         to have the remote process killed upon task timeout.
         The default is ``False`` but note that `get_pty` is forced to ``True``
@@ -60,21 +59,23 @@ class SSHOperator(BaseOperator):
     :param banner_timeout: timeout to wait for banner from the server in seconds
     """
 
-    template_fields: Sequence[str] = ('command', 'remote_host')
-    template_ext: Sequence[str] = ('.sh',)
-    template_fields_renderers = {"command": "bash"}
+    template_fields: Sequence[str] = ("command", "environment", "remote_host")
+    template_ext: Sequence[str] = (".sh",)
+    template_fields_renderers = {
+        "command": "bash",
+        "environment": "python",
+    }
 
     def __init__(
         self,
         *,
-        ssh_hook: Optional["SSHHook"] = None,
-        ssh_conn_id: Optional[str] = None,
-        remote_host: Optional[str] = None,
-        command: Optional[str] = None,
-        timeout: Optional[int] = None,
-        conn_timeout: Optional[int] = None,
-        cmd_timeout: Optional[int] = None,
-        environment: Optional[dict] = None,
+        ssh_hook: SSHHook | None = None,
+        ssh_conn_id: str | None = None,
+        remote_host: str | None = None,
+        command: str | None = None,
+        conn_timeout: int | None = None,
+        cmd_timeout: int | None = None,
+        environment: dict | None = None,
         get_pty: bool = False,
         banner_timeout: float = 30.0,
         **kwargs,
@@ -84,27 +85,13 @@ class SSHOperator(BaseOperator):
         self.ssh_conn_id = ssh_conn_id
         self.remote_host = remote_host
         self.command = command
-        self.timeout = timeout
         self.conn_timeout = conn_timeout
-        self.cmd_timeout = cmd_timeout
-        if self.conn_timeout is None and self.timeout:
-            self.conn_timeout = self.timeout
-        if self.cmd_timeout is None:
-            self.cmd_timeout = self.timeout if self.timeout else CMD_TIMEOUT
+        self.cmd_timeout = cmd_timeout if cmd_timeout else CMD_TIMEOUT
         self.environment = environment
         self.get_pty = get_pty
         self.banner_timeout = banner_timeout
 
-        if self.timeout:
-            warnings.warn(
-                'Parameter `timeout` is deprecated.'
-                'Please use `conn_timeout` and `cmd_timeout` instead.'
-                'The old option `timeout` will be removed in a future version.',
-                DeprecationWarning,
-                stacklevel=2,
-            )
-
-    def get_hook(self) -> "SSHHook":
+    def get_hook(self) -> SSHHook:
         from airflow.providers.ssh.hooks.ssh import SSHHook
 
         if self.ssh_conn_id:
@@ -131,47 +118,47 @@ class SSHOperator(BaseOperator):
 
         return self.ssh_hook
 
-    def get_ssh_client(self) -> "SSHClient":
+    def get_ssh_client(self) -> SSHClient:
         # Remember to use context manager or call .close() on this when done
-        self.log.info('Creating ssh_client')
+        self.log.info("Creating ssh_client")
         return self.get_hook().get_conn()
 
-    def exec_ssh_client_command(self, ssh_client: "SSHClient", command: str):
+    def exec_ssh_client_command(self, ssh_client: SSHClient, command: str):
         warnings.warn(
-            'exec_ssh_client_command method on SSHOperator is deprecated, call '
-            '`ssh_hook.exec_ssh_client_command` instead',
+            "exec_ssh_client_command method on SSHOperator is deprecated, call "
+            "`ssh_hook.exec_ssh_client_command` instead",
             DeprecationWarning,
         )
         assert self.ssh_hook
         return self.ssh_hook.exec_ssh_client_command(
-            ssh_client, command, timeout=self.timeout, environment=self.environment, get_pty=self.get_pty
+            ssh_client, command, timeout=self.cmd_timeout, environment=self.environment, get_pty=self.get_pty
         )
 
     def raise_for_status(self, exit_status: int, stderr: bytes) -> None:
         if exit_status != 0:
             raise AirflowException(f"SSH operator error: exit status = {exit_status}")
 
-    def run_ssh_client_command(self, ssh_client: "SSHClient", command: str) -> bytes:
+    def run_ssh_client_command(self, ssh_client: SSHClient, command: str) -> bytes:
         assert self.ssh_hook
         exit_status, agg_stdout, agg_stderr = self.ssh_hook.exec_ssh_client_command(
-            ssh_client, command, timeout=self.timeout, environment=self.environment, get_pty=self.get_pty
+            ssh_client, command, timeout=self.cmd_timeout, environment=self.environment, get_pty=self.get_pty
         )
         self.raise_for_status(exit_status, agg_stderr)
         return agg_stdout
 
-    def execute(self, context=None) -> Union[bytes, str]:
-        result: Union[bytes, str]
+    def execute(self, context=None) -> bytes | str:
+        result: bytes | str
         if self.command is None:
             raise AirflowException("SSH operator error: SSH command not specified. Aborting.")
 
         # Forcing get_pty to True if the command begins with "sudo".
-        self.get_pty = self.command.startswith('sudo') or self.get_pty
+        self.get_pty = self.command.startswith("sudo") or self.get_pty
 
         with self.get_ssh_client() as ssh_client:
             result = self.run_ssh_client_command(ssh_client, self.command)
-        enable_pickling = conf.getboolean('core', 'enable_xcom_pickling')
+        enable_pickling = conf.getboolean("core", "enable_xcom_pickling")
         if not enable_pickling:
-            result = b64encode(result).decode('utf-8')
+            result = b64encode(result).decode("utf-8")
         return result
 
     def tunnel(self) -> None:
