@@ -19,10 +19,10 @@ from __future__ import annotations
 
 from flask import Blueprint, redirect, url_for
 
-routes = Blueprint('routes', __name__)
+routes = Blueprint("routes", __name__)
 
 
-@routes.route('/')
+@routes.route("/")
 def index():
     """Main Airflow page"""
-    return redirect(url_for('Airflow.index'))
+    return redirect(url_for("Airflow.index"))
